@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Result::Jolt;
 # ABSTRACT: Jolt result handler
-$Neo4j::Driver::Result::Jolt::VERSION = '0.37'; # TRIAL
+$Neo4j::Driver::Result::Jolt::VERSION = '0.43'; # TRIAL
 
 # This package is not part of the public Neo4j::Driver API.
 
@@ -102,7 +102,6 @@ sub _gather_results {
 			# If a rollback caused by a failure fails as well,
 			# two failure events may appear on the Jolt stream.
 			# Otherwise, there is always one at most.
-			carp "Jolt error: unexpected error event $prev" unless $state == 0 || $state == 3 || $state == 4;
 			croak "Jolt error: expected reference to HASH, received " . (ref $event ? "reference to " . ref $event : "scalar") . " in $type event $prev" unless ref $event eq 'HASH';
 			$state = 4;
 			$error = $error->append_new(Internal => "Jolt error: Jolt $type event with 0 errors $prev") unless @{$event->{errors}};
@@ -122,7 +121,7 @@ sub _gather_results {
 		});
 	}
 	
-	$params->{error_handler}->($error) if ref $error;
+	$self->{info}->{_error} = $error if ref $error;
 	$self->{http_agent} = undef;
 	
 	if (@results == 1) {
@@ -291,13 +290,21 @@ sub _deep_bless {
 		return $path;
 	}
 	if ($sigil eq '@') {  # Spatial
-		# TODO
 		bless $data, $cypher_types->{point};
 		return $data;
 	}
 	if ($sigil eq 'T') {  # Temporal
-		# TODO
-		bless $data, $cypher_types->{temporal};
+		if ($cypher_types->{temporal} ne 'Neo4j::Driver::Type::Temporal') {
+			return bless $data, $cypher_types->{temporal};
+		}
+		if ($value =~ m/^-?P/) {
+			require Neo4j::Driver::Type::Duration;
+			bless $data, 'Neo4j::Driver::Type::Duration';
+		}
+		else {
+			require Neo4j::Driver::Type::DateTime;
+			bless $data, 'Neo4j::Driver::Type::DateTime';
+		}
 		return $data;
 	}
 	if ($sigil eq '#') {  # Bytes
